@@ -25,6 +25,7 @@ class GraphvizTBFormatter(BaseFormatter):
     PRIORITY_TO_END_FORMAT = '"l${table_no}_${priority_no}_${entry_no}_${instruction_no}" -> "end${table_no}" [ ltail=cluster_t${table_no}_p${priority_no}, color="#000000", fontcolor="#663333", label="NO" ]'
     BLOCK_TO_BLOCK_FORMAT = '"l${table_no}_${priority_no}_${old_entry_no}_${instruction_no}" -> "m${table_no}_${priority_no}_${entry_no}" [ ltail=cluster_t${table_no}_p${priority_no}_b${old_block_no}, lhead=cluster_t${table_no}_p${priority_no}_b${block_no}, color="transparent", label="" ]'
     TABLE_TO_TABLE_FORMAT = '"end${old_table_no}" -> "start${table_no}" [ ltail=cluster_t${old_table_no}, lhead=cluster_t${table_no}, color="#000000", fontcolor="#663333", label="" ]'
+    TABLE_TO_TABLE_FORMAT_INVISIBLE = '"end${old_table_no}" -> "start${table_no}" [ ltail=cluster_t${old_table_no}, lhead=cluster_t${table_no}, color ="transparent", label="" ]'
     INSTRUCTION_TO_RESUBMIT_FORMAT = '"l${table_no}_${priority_no}_${entry_no}_${instruction_no}" -> "resubmit${table_no}" [ dirType="none", arrowhead=none, style="dotted", color="#0000CC", fontcolor="#663333", label = "" ]'
     INSTRUCTION_TO_RESUBMIT_TABLE_FORMAT = '"l${table_no}_${priority_no}_${entry_no}_${instruction_no}" -> "resubmit_to_${resubmit_table_no}" [ dirType="none", arrowhead=none, style="dashed", color="#0000CC", fontcolor="#663333", label = "" ];'
     
@@ -156,6 +157,7 @@ node [
         self.start_to_priority_template = string.Template(self.START_TO_PRIORITY_FORMAT)
         self.priority_to_end_template = string.Template(self.PRIORITY_TO_END_FORMAT)
         self.table_to_table_template = string.Template(self.TABLE_TO_TABLE_FORMAT)
+        self.table_to_table_invisible_template = string.Template(self.TABLE_TO_TABLE_FORMAT_INVISIBLE)
         self.resubmit_template = string.Template(self.RESUBMIT_FORMAT)
         self.resubmit_table_template = string.Template(self.RESUBMIT_TABLE_FORMAT)
         self.block_to_block_template = string.Template(self.BLOCK_TO_BLOCK_FORMAT)
@@ -184,6 +186,10 @@ node [
 
         tables = self._tables.keys()
         for t_no in sorted(tables, key=lambda x: int(x)):
+            if self.output_target_tables != []:
+                if not t_no in self.output_target_tables:
+                    continue
+                    
             n_priority_in_table = 0
             self.resubmit_loop = False
             self.resubmit_edges = []
@@ -402,9 +408,12 @@ node [
             "instruction_no":instruction_no})
 
     def _format_instruction_to_resubmit(self, table_no, priority_no, entry_no, instruction_no):
-        return self.instruction_to_resubmit_template.substitute( \
-            {"table_no":table_no, "priority_no":priority_no, "entry_no":entry_no, \
-            "instruction_no":instruction_no})
+        if self.output_resubmit_loop:
+            return self.instruction_to_resubmit_template.substitute( \
+                {"table_no":table_no, "priority_no":priority_no, "entry_no":entry_no, \
+                "instruction_no":instruction_no})
+        else:
+            return ""
 
     def _format_instruction_to_resubmit_table(self, table_no, priority_no, entry_no, instruction_no, resubmit_table_no):
         return self.instruction_to_resubmit_table_template.substitute( \
@@ -438,9 +447,12 @@ node [
         return self.INDENT_IN_TABLE + self.resubmit_table_template.substitute({"resubmit_table_no":resubmit_table_no})
 
     def _format_resubmit_loop(self, table_no):
-        if self.resubmit_loop:
-            return self.INDENT_IN_TABLE + self.resubmit_template.substitute({"table_no":table_no}) \
-                + "\n" + self.INDENT_IN_TABLE + self.resubmit_to_start_template.substitute({"table_no":table_no})
+        if self.output_resubmit_loop:
+            if self.resubmit_loop:
+                return self.INDENT_IN_TABLE + self.resubmit_template.substitute({"table_no":table_no}) \
+                    + "\n" + self.INDENT_IN_TABLE + self.resubmit_to_start_template.substitute({"table_no":table_no})
+            else:
+                return ""
         else:
             return ""
 
@@ -460,8 +472,11 @@ node [
         return "\n".join(format_resubmit_tables)
 
     def _format_table_to_table(self, table_no, old_table_no):
-       return self.INDENT_IN_GRAPH + self.table_to_table_template.substitute({"table_no":table_no, "old_table_no":old_table_no})
-
+        if self.output_target_tables != []:
+            return self.INDENT_IN_GRAPH + self.table_to_table_invisible_template.substitute({"table_no":table_no, "old_table_no":old_table_no})
+        else:
+            return self.INDENT_IN_GRAPH + self.table_to_table_template.substitute({"table_no":table_no, "old_table_no":old_table_no})
+        
     def _format_group(self, entry_name, group_no):
         return self.group_template.substitute({"entry_name":entry_name, "group_no":group_no})
 
